SystemOrganization addCategory: #ConfigurationOfFileSystemGit!

Object subclass: #ConfigurationOfFileSystemGit
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfFileSystemGit'!

!ConfigurationOfFileSystemGit class methodsFor: 'development support' stamp: 'MML 12/30/2012 17:50'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfFileSystemGit class methodsFor: 'private' stamp: 'MML 12/30/2012 17:50'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfFileSystemGit class methodsFor: 'private' stamp: 'MML 12/30/2012 17:50'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfFileSystemGit class methodsFor: 'private' stamp: 'MML 12/30/2012 17:50'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfFileSystemGit class methodsFor: 'metacello tool support' stamp: 'MML 12/30/2012 17:50'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfFileSystemGit class methodsFor: 'loading' stamp: 'MML 12/30/2012 17:50'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfFileSystemGit class methodsFor: 'loading' stamp: 'MML 12/30/2012 17:50'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfFileSystemGit class methodsFor: 'loading' stamp: 'MML 12/30/2012 17:50'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfFileSystemGit class methodsFor: 'accessing' stamp: 'MML 12/30/2012 17:50'!
project

	^self new project! !

!ConfigurationOfFileSystemGit class methodsFor: 'development support' stamp: 'MML 12/30/2012 17:50'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfFileSystemGit methodsFor: 'baselines' stamp: 'MML 12/30/2012 17:50'!
baseline10: spec
	<version: '1.0-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://ss3/gemstone.com/ss/FileSystem-Git'.
		spec 
			package: 'FileSystem-Git-Core';
			package: 'FileSystem-Git-Tests' with: [
				spec requires: #('FileSystem-Git-Core' ). ];
			package: 'FileSystem-Git-Help';
			package: 'FileSystem-Git-Plumbing' with: [
				spec requires: #('FileSystem-Git-Core' ). ];
			package: 'FileSystem-Git-Remote' with: [
				spec requires: #('FileSystem-Git-Core' ). ];
			package: 'FileSystem-Git-Monticello' with: [
				spec requires: #('FileSystem-Git-Core' 'FileSystem-Git-Plumbing' ). ];
			package: 'FileSystem-Git-Notifications'.
		spec 
			group: 'default' with: #('Core' 'Tests' );
			group: 'extensions' with: #('FileSystem-Git-Remote' 'FileSystem-Git-Monticello' );
			group: 'development' with: #('default' 'extensions' );
			group: 'Core' with: #('FileSystem-Git-Core' 'FileSystem-Git-Plumbing' 'FileSystem-Git-Notifications' 'FileSystem-Git-Help' );
			group: 'Tests' with: #('FileSystem-Git-Tests' ). ].
! !

!ConfigurationOfFileSystemGit methodsFor: 'accessing' stamp: 'MML 12/30/2012 17:50'!
customProjectAttributes
	 "Edit to return a collection of any custom attributes e.g. for conditional loading: Array with: #'Condition1' with: #'Condition2.
	For more information see: http://code.google.com/p/metacello/wiki/CustomProjectAttrributes"

	^ #().! !

!ConfigurationOfFileSystemGit methodsFor: 'symbolic versions' stamp: 'MML 12/30/2012 17:50'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '1.0'.
! !

!ConfigurationOfFileSystemGit methodsFor: 'accessing' stamp: 'MML 12/30/2012 17:50'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		project := MetacelloMCProject new projectAttributes: self customProjectAttributes. 
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self project: project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfFileSystemGit methodsFor: 'versions' stamp: 'MML 12/30/2012 17:50'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'initial version'.
		spec author: 'MaxLeske'.
		spec timestamp: '12/30/2012 17:50'.
		spec 
			package: 'FileSystem-Git-Core' with: 'FileSystem-Git-Core';
			package: 'FileSystem-Git-Tests' with: 'FileSystem-Git-Tests';
			package: 'FileSystem-Git-Help' with: 'FileSystem-Git-Help';
			package: 'FileSystem-Git-Plumbing' with: 'FileSystem-Git-Plumbing';
			package: 'FileSystem-Git-Remote' with: 'FileSystem-Git-Remote';
			package: 'FileSystem-Git-Monticello' with: 'FileSystem-Git-Monticello';
			package: 'FileSystem-Git-Notifications' with: 'FileSystem-Git-Notifications'. ].
! !
